@@ -1,5 +1,5 @@
 ; AisleRiot - canfield.scm
-; Copyright (C) 1998 Rosanna Yuen <rwsy@mit.edu>
+; Copyright (C) 1998, 2003 Rosanna Yuen <rwsy@mit.edu>
 ;
 ; This game is free software; you can redistribute it and/or modify
 ; it under the terms of the GNU General Public License as published by
@@ -68,29 +68,29 @@
 					(get-redeals-string))))
 
 (define (get-stock-no-string)
-  (string-append "Stock left:  " 
+  (string-append (_"Stock left:  ")
 		 (number->string (length (get-cards 0)))))
 
 (define (get-reserve-no-string)
-  (string-append "Reserve left:  " 
+  (string-append (_"Reserve left:  ")
 		 (number->string (length (get-cards 6)))))
 
 (define (get-base-string)
   (cond ((and (> BASE-VAL 1)
 	      (< BASE-VAL 11))
-	 (string-append "Base Card:  " (number->string BASE-VAL)))
+	 (string-append (_"Base Card:  ") (number->string BASE-VAL)))
 	((= BASE-VAL 1)
-	 "Base Card:  Ace")
+	 (_"Base Card:  Ace"))
 	((= BASE-VAL 11)
-	 "Base Card:  Jack")
+	 (_"Base Card:  Jack"))
 	((= BASE-VAL 12)
-	 "Base Card:  Queen")
+	 (_"Base Card:  Queen"))
 	((= BASE-VAL 13)
-	 "Base Card:  King")
+	 (_"Base Card:  King"))
 	(#t #f)))
 
 (define (get-redeals-string)
-  (string-append "Redeals left:  "
+  (string-append (_"Redeals left:  ")
 		 (number->string (- 2 FLIP-COUNTER))))
 
 (define (button-pressed slot-id card-list)
@@ -230,17 +230,17 @@
 
 (define (deal-possible?)
   (if (not (empty-slot? 0))
-      (list 0 "Deal a new card from the deck")
+      (list 0 (_"Deal a new card from the deck"))
       (if (and (< FLIP-COUNTER 2)
 	       (not (empty-slot? 1)))
-	  (list 0 "Move waste back to stock")
+	  (list 0 (_"Move waste back to stock"))
 	  #f)))
 
 (define (move-up? card slot)
   (or (if (empty-slot? slot)
 	  (if (= (get-value card)
 		 BASE-VAL)
-	      (list 1 (get-name card) "empty slot on foundation")
+	      (list 1 (get-name card) (_"empty slot on foundation"))
 	      #f)
 	  (and (= (get-suit card)
 		  (get-suit (get-top-card slot)))
@@ -262,7 +262,7 @@
 
 (define (tabled card slot)
   (or (if (empty-slot? slot)
-	  (list 1 (get-name card) "empty space on tableau")
+	  (list 1 (get-name card) (_"empty space on tableau"))
 	  (and (eq? (is-black? card)
 		    (is-red? (get-top-card slot)))
 	       (or (and (= (get-value card) king)
@@ -311,7 +311,7 @@
       (to-tableau? '(6 1))
       (move-column? '(7 8 9 10))
       (deal-possible?)
-      (list 0 "Try rearranging the cards")))
+      (list 0 (_"Try rearranging the cards"))))
 
 (define (get-options) #f)
 
