@@ -52,11 +52,11 @@
 					(get-redeals-string))))
 
 (define (get-redeals-string)
-  (string-append (gettext "Redeals left:  ")
+  (string-append (_"Redeals left:  ")
 		 (number->string (- 2 FLIP-COUNTER))))
 
 (define (get-stock-no-string)
-  (string-append (gettext "Stock left:  ") 
+  (string-append (_"Stock left:  ") 
 		 (number->string (length (get-cards 0)))))
 
 (define (button-pressed slot-id card-list)
@@ -132,9 +132,9 @@
 
 (define (dealable?)
   (or (and (not (empty-slot? 0))
-	   (list 0 (gettext "Deal another round")))
+	   (list 0 (_"Deal another round")))
       (and (< FLIP-COUNTER 2)
-	   (list 0 (gettext "Reshuffle cards")))))
+	   (list 0 (_"Reshuffle cards")))))
 
 (define (get-hint)
   (or (movable? 5 1)
