@@ -1,5 +1,5 @@
 /* AisleRiot - sol.c
- * Copyright (C) 1998, 2001 Jonathan Blandford <jrb@alum.mit.edu>
+ * Copyright (C) 1998, 2001, 2003 Jonathan Blandford <jrb@alum.mit.edu>
  *
  * This game is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -54,6 +54,11 @@ GdkPixmap        *surface;
 GdkPixmap        *moving_card_pixmap;
 GtkObject*       card_deck;
 GdkCardDeckOptions deck_options = NULL;
+gboolean         dont_save = FALSE; /* If the game is selected on the
+                                     * command line we assume that it is
+                                     * special and don't save the state.
+                                     * This is essential for Freecell
+                                     * emulation.*/
 
 guint            score;
 /* guint            game_seconds;*/
@@ -150,7 +155,7 @@ void eval_installed_file (char *file)
     GtkWidget *w = gtk_message_dialog_new (GTK_WINDOW(app),
                                        GTK_DIALOG_DESTROY_WITH_PARENT,
                                        GTK_MESSAGE_ERROR,
-                                       GTK_BUTTONS_CLOSE,
+                                       GTK_BUTTONS_OK,
                                        message);
 
     gtk_dialog_run (GTK_DIALOG(w));
@@ -206,7 +211,7 @@ void new_game (gchar* file, guint *seedp )
     eval_installed_file (file);
     if(game_name) {
       g_snprintf(buf, sizeof (buf), "%s/%s", _("Help"), game_name);
-      gnome_app_remove_menus (GNOME_APP (app), buf, 1);
+/*      gnome_app_remove_menus (GNOME_APP (app), buf, 1); */
       if(rules_help[0].user_data) {
 #if 0
 	GnomeHelpMenuEntry *entry = 
@@ -219,7 +224,8 @@ void new_game (gchar* file, guint *seedp )
     }
     game_name = game_file_to_name (file);
 
-    save_state (gnome_master_client ());
+    if (!dont_save)
+      save_state (gnome_master_client ());
 
     rules_help[0].label = game_name;
     rules_help[0].user_data = game_file_to_help_entry(file);
@@ -565,6 +571,7 @@ int main (int argc, char *argv [])
   for (i = 0; i < n_games; i++) {
     gchar *game_name = game_file_to_name (game_dents[i]->d_name);
     if (!strcasecmp (variation, game_name)) {
+      dont_save = TRUE;
       start_game = g_strdup ((gchar*) game_dents[i]->d_name);
       g_free (game_name);
       break;
