@@ -16,6 +16,16 @@
 ; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 ; USA
 
+(use-modules (ice-9 format))
+
+;; Compatibility code so we run on both guile 1.3 and 1.5
+
+(define (eval-1 code)
+  (if (string<? (version) "1.5")
+      (eval code)
+      (eval code (current-module))))
+        
+
 ;; Constants:
 
 (define jack 11)
@@ -254,7 +264,7 @@
 	((eq? (get-suit card) spade) black)
 	((eq? (get-suit card) heart) red)
 	((eq? (get-suit card) diamond) red)
-	(#t (gettext "Unknown color"))))
+	(#t (_"Unknown color"))))
 
 (define (get-value card) 
   (car card))
@@ -318,39 +328,98 @@
 (define (display-list . objs)
   (map display objs) (newline))
 
-; hint procedures: these will be superceeded shortly.
+; hint procedures
 (define (get-value-name value)
-  (cond ((eq? value ace) (gettext "ace"))
-	((eq? value 2) (gettext "two"))
-	((eq? value 3) (gettext "three"))
-	((eq? value 4) (gettext "four"))
-	((eq? value 5) (gettext "five"))
-	((eq? value 6) (gettext "six"))
-	((eq? value 7) (gettext "seven"))
-	((eq? value 8) (gettext "eight"))
-	((eq? value 9) (gettext "nine"))
-	((eq? value 10) (gettext "ten"))
-	((eq? value jack) (gettext "jack"))
-	((eq? value queen) (gettext "queen"))
-	((eq? value king) (gettext "king"))
-	(#t (gettext "Unknown value"))))
+  (cond ((eq? value ace) (_"ace"))
+        ((eq? value 2) (_"two"))
+        ((eq? value 3) (_"three"))
+        ((eq? value 4) (_"four"))
+        ((eq? value 5) (_"five"))
+        ((eq? value 6) (_"six"))
+        ((eq? value 7) (_"seven"))
+        ((eq? value 8) (_"eight"))
+        ((eq? value 9) (_"nine"))
+        ((eq? value 10) (_"ten"))
+        ((eq? value jack) (_"jack"))
+        ((eq? value queen) (_"queen"))
+        ((eq? value king) (_"king"))
+        (#t (_"Unknown value"))))
 
 (define (get-suit-name suit)
-  (cond ((eq? suit club) (gettext "clubs"))
-	((eq? suit spade) (gettext "spades"))
-	((eq? suit heart) (gettext "hearts"))
-	((eq? suit diamond) (gettext "diamonds"))
-	(#t (gettext "Unknown suit"))))
+  (cond ((eq? suit club) (_"clubs"))
+        ((eq? suit spade) (_"spades"))
+        ((eq? suit heart) (_"hearts"))
+        ((eq? suit diamond) (_"diamonds"))
+        (#t (_"Unknown suit"))))
 
 (define (get-joker-name card) 
-  (if (is-black? card) (gettext "black joker") (gettext "red joker")))
+  (if (is-black? card) (_"black joker") (_"red joker")))
 
 (define (get-name card)
-  (if (is-joker? card)
-      (get-joker-name card)
-      (string-append (get-value-name (get-value card)) 
-		     (gettext " of ")
-		     (get-suit-name (get-suit card)))))
+  (let ((value (get-value card)) (suit (get-suit card)))
+    (if (is-joker? card)
+        (get-joker-name card)
+        (cond ((eq? suit club) 
+               (cond ((eq? value ace) (_"the ace of clubs"))
+                     ((eq? value 2) (_"the two of clubs"))
+                     ((eq? value 3) (_"the three of clubs"))
+                     ((eq? value 4) (_"the four of clubs"))
+                     ((eq? value 5) (_"the five of clubs"))
+                     ((eq? value 6) (_"the six of clubs"))
+                     ((eq? value 7) (_"the seven of clubs"))
+                     ((eq? value 8) (_"the eight of clubs"))
+                     ((eq? value 9) (_"the nine of clubs"))
+                     ((eq? value 10) (_"the ten of clubs"))
+                     ((eq? value jack) (_"the jack of clubs"))
+                     ((eq? value queen) (_"the queen of clubs"))
+                     ((eq? value king) (_"the king of clubs"))
+                     (#t (_"the unknown card"))))
+              ((eq? suit spade) 
+               (cond ((eq? value ace) (_"the ace of spades"))
+                     ((eq? value 2) (_"the two of spades"))
+                     ((eq? value 3) (_"the three of spades"))
+                     ((eq? value 4) (_"the four of spades"))
+                     ((eq? value 5) (_"the five of spades"))
+                     ((eq? value 6) (_"the six of spades"))
+                     ((eq? value 7) (_"the seven of spades"))
+                     ((eq? value 8) (_"the eight of spades"))
+                     ((eq? value 9) (_"the nine of spades"))
+                     ((eq? value 10) (_"the ten of spades"))
+                     ((eq? value jack) (_"the jack of spades"))
+                     ((eq? value queen) (_"the queen of spades"))
+                     ((eq? value king) (_"the king of spades"))
+                     (#t (_"the unknown card"))))
+              ((eq? suit heart) 
+               (cond ((eq? value ace) (_"the ace of hearts"))
+                     ((eq? value 2) (_"the two of hearts"))
+                     ((eq? value 3) (_"the three of hearts"))
+                     ((eq? value 4) (_"the four of hearts"))
+                     ((eq? value 5) (_"the five of hearts"))
+                     ((eq? value 6) (_"the six of hearts"))
+                     ((eq? value 7) (_"the seven of hearts"))
+                     ((eq? value 8) (_"the eight of hearts"))
+                     ((eq? value 9) (_"the nine of hearts"))
+                     ((eq? value 10) (_"the ten of hearts"))
+                     ((eq? value jack) (_"the jack of hearts"))
+                     ((eq? value queen) (_"the queen of hearts"))
+                     ((eq? value king) (_"the king of hearts"))
+                     (#t (_"the unknown card"))))
+              ((eq? suit diamond) 
+               (cond ((eq? value ace) (_"the ace of diamonds"))
+                     ((eq? value 2) (_"the two of diamonds"))
+                     ((eq? value 3) (_"the three of diamonds"))
+                     ((eq? value 4) (_"the four of diamonds"))
+                     ((eq? value 5) (_"the five of diamonds"))
+                     ((eq? value 6) (_"the six of diamonds"))
+                     ((eq? value 7) (_"the seven of diamonds"))
+                     ((eq? value 8) (_"the eight of diamonds"))
+                     ((eq? value 9) (_"the nine of diamonds"))
+                     ((eq? value 10) (_"the ten of diamonds"))
+                     ((eq? value jack) (_"the jack of diamonds"))
+                     ((eq? value queen) (_"the queen of diamonds"))
+                     ((eq? value king) (_"the king of diamonds"))
+                     (#t (_"the unknown card"))))
+              (#t (_"the unknown card"))))))
 
 (define (move-n-cards! start-slot end-slot cards)
   (add-cards! end-slot cards))
@@ -517,7 +586,7 @@
   (lambda (names)
     (if (equal? '() names)
         '()
-        (cons (eval (car names)) 
+        (cons (eval-1 (car names)) 
               (save-variables (cdr names))))))
 
 ; Restore all the state variables for a game
@@ -525,7 +594,7 @@
   (lambda (names values)
     (or (equal? '() names)
         (begin
-          (eval (list 'set! (car names) (car values)))
+          (eval-1 (list 'set! (car names) (car values)))
           (restore-variables (cdr names) (cdr values))
           ))))
 
