@@ -87,9 +87,7 @@ gint8 board[7][7] = {{0,0,0,0,0,0,0},
 		     {0,0,0,0,0,0,0}};
 
 
-MoveHistory game[500];
-
-gint8 move_count = 0;
+MoveHistory * game = NULL;
 
 extern guint flip_final_id;
 
@@ -249,12 +247,18 @@ gboolean quit_game_cb(GtkWidget *widget, gpointer data)
       return TRUE;
   }
 
-  if (flip_pixmaps_id)
-    gtk_timeout_remove(flip_pixmaps_id);
-  if (black_computer_id)
-    gtk_timeout_remove(black_computer_id);
-  if (white_computer_id)
-    gtk_timeout_remove(white_computer_id);
+  if (flip_pixmaps_id) {
+    g_source_remove (flip_pixmaps_id);
+    flip_pixmaps_id = 0;
+  }
+  if (black_computer_id) {
+    g_source_remove (black_computer_id);
+    black_computer_id= 0;
+  }
+  if (white_computer_id) {
+    g_source_remove (white_computer_id);
+    white_computer_id = 0;
+  }
 
   if(buffer_pixmap)
     gdk_drawable_unref(buffer_pixmap);
@@ -297,36 +301,39 @@ void undo_move_cb(GtkWidget *widget, gpointer data) {
 
   gint8 which_computer;
   gint i, j;
+  MoveHistory * temp;
   
-  if((black_computer_level && white_computer_level) || !move_count)
+  if((black_computer_level && white_computer_level) || !game || !game->prev)
     return;
   
   if (flip_final_id) {
-    gtk_timeout_remove(flip_final_id);
+    g_source_remove (flip_final_id);
     flip_final_id = 0;
   }
   
   game_in_progress = 1;
+
+  temp = game;
+  game = game->prev;
+  g_free (temp);
   
   if(black_computer_level || white_computer_level) {
     if(black_computer_level)
       which_computer = BLACK_TURN;
     else
       which_computer = WHITE_TURN;
-    move_count--;
-    while(game[move_count].me == which_computer && move_count > 0) {
-      pixmaps[game[move_count].x][game[move_count].y] = 100;
-      move_count--;
+    while(game->prev && game->me == which_computer) {
+      pixmaps[game->x][game->y] = 100;
+      temp = game;
+      game = game->prev;
+      g_free (temp);
     }
-    pixmaps[game[move_count].x][game[move_count].y] = 100;
-    memcpy(board, game[move_count].board, sizeof(gint8) * 7 * 7);
-  } else {
-    move_count--;
-    memcpy(board, game[move_count].board, sizeof(gint8) * 7 * 7);
-    pixmaps[game[move_count].x][game[move_count].y] = 100;
   }
+
+  pixmaps[game->x][game->y] = 100;  
+  memcpy(board, game->board, sizeof(gint8) * 7 * 7);
   
-  whose_turn = game[move_count].me;
+  whose_turn = game->me;
   
   if(whose_turn == WHITE_TURN)
     gui_message(_("Light's move"));
@@ -354,6 +361,16 @@ void undo_move_cb(GtkWidget *widget, gpointer data) {
   }
   
   tiles_to_flip = 1;
+
+  /* Cancel impending computer moves. */
+  if (black_computer_id) {
+    g_source_remove (black_computer_id);
+    black_computer_id = 0;
+  }
+  if (white_computer_id) {
+    g_source_remove (white_computer_id);
+    white_computer_id = 0;
+  }
   
   check_computer_players ();
 }
@@ -374,7 +391,7 @@ void black_level_cb(GtkWidget *widget, gpointer data) {
     games_clock_set_seconds(GAMES_CLOCK(time_display), 0);
     timer_valid = 0;
   }
-  
+
   check_computer_players();
 }
 
@@ -395,7 +412,7 @@ void white_level_cb(GtkWidget *widget, gpointer data)
     games_clock_set_seconds(GAMES_CLOCK(time_display), 0);
     timer_valid = 0;
   }
-  
+
   check_computer_players();
 }
 
@@ -651,16 +668,22 @@ gint flip_pixmaps(gpointer data) {
 }
 
 void init_new_game() {
-  
   guint i, j;
-
+  MoveHistory * temp;
+  
   if (flip_final_id) {
-    gtk_timeout_remove(flip_final_id);
+    g_source_remove (flip_final_id);
     flip_final_id = 0;
   }
 
   game_in_progress = 1;
-  move_count = 0;
+  while (game) {
+    temp = game;
+    game = game->prev;
+    g_free (temp);
+  }
+  game = g_malloc (sizeof(MoveHistory));
+  game->prev = NULL;
   
   for(i = 0; i < 7; i++)
     for(j = 0; j < 7; j++)
@@ -677,7 +700,7 @@ void init_new_game() {
   gui_status();
   
   memcpy(pixmaps, board, sizeof(gint8) * 7 * 7);
-  memcpy(game[0].board, board, sizeof(gint8) * 7 * 7);
+  memcpy(game->board, board, sizeof(gint8) * 7 * 7);
 
   for(i = 0; i < 7; i++)
     for(j = 0; j < 7; j++)
@@ -704,7 +727,7 @@ void init_new_game() {
     gtk_widget_set_sensitive(time_display, FALSE);
     timer_valid = 0;
   }
- 
+
   check_computer_players();
 }
 
@@ -797,33 +820,34 @@ void gui_message(gchar *message) {
 }
 
 guint check_computer_players() {
-
-
-  if(black_computer_level && whose_turn == BLACK_TURN)
+  
+  if(black_computer_level && whose_turn == BLACK_TURN) {
     switch(black_computer_level) {
     case 1:
-      black_computer_id = gtk_timeout_add(computer_speed, (GtkFunction)computer_move_1, (gpointer) BLACK_TURN);
+      black_computer_id = g_timeout_add(computer_speed, (GtkFunction)computer_move_1, (gpointer) BLACK_TURN);
       break;
     case 2:
-      black_computer_id = gtk_timeout_add(computer_speed, (GtkFunction)computer_move_2, (gpointer) BLACK_TURN);
+      black_computer_id = g_timeout_add(computer_speed, (GtkFunction)computer_move_2, (gpointer) BLACK_TURN);
       break;
     case 3:
-      black_computer_id = gtk_timeout_add(computer_speed, (GtkFunction)computer_move_3, (gpointer) BLACK_TURN);
+      black_computer_id = g_timeout_add(computer_speed, (GtkFunction)computer_move_3, (gpointer) BLACK_TURN);
       break;
     }
+  }
   
-  if(white_computer_level && whose_turn == WHITE_TURN)
+  if(white_computer_level && whose_turn == WHITE_TURN) {
     switch(white_computer_level) {
     case 1:
-      white_computer_id = gtk_timeout_add(computer_speed, (GtkFunction)computer_move_1, (gpointer) WHITE_TURN);
+      white_computer_id = g_timeout_add(computer_speed, (GtkFunction)computer_move_1, (gpointer) WHITE_TURN);
       break;
     case 2:
-      white_computer_id = gtk_timeout_add(computer_speed, (GtkFunction)computer_move_2, (gpointer) WHITE_TURN);
+      white_computer_id = g_timeout_add(computer_speed, (GtkFunction)computer_move_2, (gpointer) WHITE_TURN);
       break;
     case 3:
-      white_computer_id = gtk_timeout_add(computer_speed, (GtkFunction)computer_move_3, (gpointer) WHITE_TURN);
+      white_computer_id = g_timeout_add(computer_speed, (GtkFunction)computer_move_3, (gpointer) WHITE_TURN);
       break;
     }
+  }
   
   return(TRUE);
 }
