@@ -154,6 +154,10 @@ private:
 
 	bool fastFall;
 	int fastFallPoints;
+        bool dropBlock;
+
+        GnomeCanvasItem * pauseMessage;
+        GnomeCanvasItem * gameoverMessage;
 };
 
 #endif // __tetris_h__
