@@ -34,6 +34,7 @@
 static GtkWidget *mfield;
 static GtkWidget *pref_dialog;
 static GtkWidget *rbutton;
+static GtkWidget *ralign;
 static GConfClient *conf_client;
 GtkWidget *window;
 GtkWidget *flabel;
@@ -111,7 +112,7 @@ void update_score_state ()
 {
         gchar **names = NULL;
         gfloat *scores = NULL;
-        time_t *scoretimes = NULL;
+       time_t *scoretimes = NULL;
 	gint top;
 	gchar buf[64];
 
@@ -154,17 +155,25 @@ void new_game(GtkWidget *widget, gpointer data)
 	gtk_minefield_restart(GTK_MINEFIELD(mfield));
 	set_flabel(GTK_MINEFIELD(mfield));
 
-	gtk_widget_hide (rbutton);
+	gtk_widget_hide (ralign);
 	gtk_widget_show (mfield);
 }
 
 void focus_out_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
 {
+        GtkRequisition req;
+
 	if (GAMES_CLOCK(clk)->timer_id == -1)
 		return;
 
+        /* This is a complete abuse of the sizing system, but it seems to
+         * be the only way to keep the window the same size when we substitute
+         * the "Press to resume" button, but still allow it to resize when we 
+         * resize the field. */
+        gtk_widget_size_request (mfield, &req);
+        gtk_widget_set_size_request (ralign, req.width, req.height);
 	gtk_widget_hide (mfield);
-	gtk_widget_show (rbutton);
+	gtk_widget_show (ralign);
 
 	gtk_widget_grab_focus(rbutton);
 
@@ -173,7 +182,7 @@ void focus_out_cb (GtkWidget *widget, GdkEventFocus *event, gpointer data)
 
 void resume_game_cb (GtkButton *widget, gpointer data)
 {
-	gtk_widget_hide (rbutton);
+	gtk_widget_hide (ralign);
 	gtk_widget_show (mfield);
 
 	games_clock_start(GAMES_CLOCK(clk));
@@ -294,8 +303,7 @@ about(GtkWidget *widget, gpointer data)
 	const gchar *translator_credits = _("translator_credits");
 	
 	if (about) {
-		gdk_window_raise (about->window);
-		gdk_window_show (about->window);
+                gtk_window_present (GTK_WINDOW (about));
 		return;
 	}
 
@@ -365,7 +373,7 @@ gconf_key_change_cb (GConfClient *client, guint cnxn_id,
 		int i;
 		i = value ? gconf_value_get_int (value) : 40;
 		if (nmines != i) {
-			nmines = range (i, 1, xsize * ysize);
+			nmines = range (i, 1, xsize * ysize - 2);
 			gtk_minefield_set_mines(GTK_MINEFIELD(mfield), nmines, minesize);
 			new_game (mfield, NULL);
 		}
@@ -405,13 +413,28 @@ size_radio_callback(GtkWidget *widget, gpointer data)
 	gtk_widget_set_sensitive(cframe, fsc == 3);
 }
 
+void fix_nmines (int xsize, int ysize)
+{
+  int maxmines;
+
+  /* Fix up the maximum number of mines so that there is always at least two
+   * free spaces. It could in theory be left at one, but that gives an
+   * instant win situation. */
+  maxmines = xsize*ysize - 2;
+  if (nmines > maxmines) {
+    gconf_client_set_int (conf_client, KEY_NMINES, maxmines, NULL);
+    gtk_spin_button_set_value (GTK_SPIN_BUTTON(mentry), maxmines);
+  }
+  gtk_spin_button_set_range (GTK_SPIN_BUTTON(mentry), 1, maxmines);
+}
+
 static void
 xsize_spin_cb (GtkSpinButton *spin, gpointer data)
 {
 	int size = gtk_spin_button_get_value_as_int (spin);
 	gconf_client_set_int (conf_client, KEY_XSIZE,
 			      size, NULL);
-
+        fix_nmines(size,ysize);
 }
 
 static void
@@ -420,7 +443,7 @@ ysize_spin_cb (GtkSpinButton *spin, gpointer data)
 	int size = gtk_spin_button_get_value_as_int (spin);
 	gconf_client_set_int (conf_client, KEY_YSIZE,
 			      size, NULL);
-
+        fix_nmines(xsize,size);
 }
 
 static void
@@ -451,9 +474,12 @@ static void preferences_callback (GtkWidget *widget, gpointer data)
 	GtkWidget *table2;
 	GtkWidget *label2;
 	char *numstr;
-	
-	if (pref_dialog)
+        gchar * label;
+        
+	if (pref_dialog) {
+                gtk_window_present (GTK_WINDOW (pref_dialog));
 		return;
+        }
 
 	table = gtk_table_new (2, 2, FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (table), GNOME_PAD);
@@ -461,7 +487,9 @@ static void preferences_callback (GtkWidget *widget, gpointer data)
 	gtk_table_set_row_spacings (GTK_TABLE (table), GNOME_PAD);
 	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD);
 
-	frame = gtk_frame_new (_("<b>Field size</b>"));
+        label = g_strdup_printf("<b>%s</b>",_("Field size"));
+	frame = gtk_frame_new (label);
+        g_free(label);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 	gtk_label_set_use_markup (GTK_LABEL (gtk_frame_get_label_widget (GTK_FRAME (frame))), TRUE);
 	gtk_container_set_border_width (GTK_CONTAINER (frame), 0);
@@ -518,7 +546,9 @@ static void preferences_callback (GtkWidget *widget, gpointer data)
 	gtk_table_attach (GTK_TABLE (table), frame, 0, 1, 0, 1, GTK_EXPAND |
 			GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
 
-	cframe = gtk_frame_new (_("<b>Custom size</b>"));
+        label = g_strdup_printf("<b>%s</b>",_("Custom size"));
+	cframe = gtk_frame_new (label);
+        g_free(label);
 	gtk_frame_set_shadow_type (GTK_FRAME (cframe), GTK_SHADOW_NONE);
 	gtk_label_set_use_markup (GTK_LABEL (gtk_frame_get_label_widget (GTK_FRAME (cframe))), TRUE);
 	gtk_container_set_border_width (GTK_CONTAINER (cframe), 0);
@@ -530,6 +560,20 @@ static void preferences_callback (GtkWidget *widget, gpointer data)
 	gtk_widget_show (table2);
 	gtk_table_set_row_spacings (GTK_TABLE (table2), GNOME_PAD);
 
+	label2 = gtk_label_new (_("Number of mines:"));
+	gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
+	gtk_widget_show (label2);
+	gtk_table_attach (GTK_TABLE (table2), label2, 0, 1, 2, 3,
+			GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
+	/* TODO: fix this when gconfised correctly */
+	mentry = gtk_spin_button_new_with_range (1, XSIZE_MAX*YSIZE_MAX, 1);
+	g_signal_connect (GTK_OBJECT (mentry), "value-changed",
+			GTK_SIGNAL_FUNC (nmines_spin_cb), NULL);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON(mentry), nmines);
+	gtk_table_attach (GTK_TABLE (table2), mentry, 1, 2, 2, 3, GTK_FILL, GTK_EXPAND
+			| GTK_FILL, 0, 0);
+	gtk_widget_show (mentry);
+
 	label2 = gtk_label_new (_("Horizontal:"));
 	gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
 	gtk_widget_show (label2);
@@ -558,20 +602,6 @@ static void preferences_callback (GtkWidget *widget, gpointer data)
 			| GTK_FILL, 0, 0);
 	gtk_widget_show (yentry);
 
-	label2 = gtk_label_new (_("Number of mines:"));
-	gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
-	gtk_widget_show (label2);
-	gtk_table_attach (GTK_TABLE (table2), label2, 0, 1, 2, 3,
-			GTK_EXPAND | GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
-	/* TODO: fix this when gconfised correctly */
-	mentry = gtk_spin_button_new_with_range (1, XSIZE_MAX*YSIZE_MAX, 1);
-	g_signal_connect (GTK_OBJECT (mentry), "value-changed",
-			GTK_SIGNAL_FUNC (nmines_spin_cb), NULL);
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON(mentry), nmines);
-	gtk_table_attach (GTK_TABLE (table2), mentry, 1, 2, 2, 3, GTK_FILL, GTK_EXPAND
-			| GTK_FILL, 0, 0);
-	gtk_widget_show (mentry);
-
 	gtk_container_add (GTK_CONTAINER (cframe), table2);
 
 	gtk_table_attach (GTK_TABLE (table), cframe, 1, 2, 0, 1, GTK_EXPAND |
@@ -710,8 +740,8 @@ main (int argc, char *argv[])
 	GtkWidget *status_table;
 	GtkWidget *button_table;
         GtkWidget *align;
+        GtkWidget *box;        
         GtkWidget *label;
-	GtkWidget *box;
 	GnomeClient *client;
 
 	gnome_score_init("gnomine");
@@ -837,10 +867,13 @@ main (int argc, char *argv[])
 	mfield = gtk_minefield_new();
 	gtk_box_pack_start(GTK_BOX(box), mfield, TRUE, TRUE, 0);
 
+        ralign = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
+	gtk_box_pack_start (GTK_BOX(box), ralign, TRUE, TRUE, 0);
 	rbutton = gtk_button_new_with_label ("Press to resume");
 	g_signal_connect (GTK_OBJECT(rbutton), "clicked", 
 			    GTK_SIGNAL_FUNC (resume_game_cb), NULL);
-	gtk_box_pack_start(GTK_BOX(box), rbutton, TRUE, TRUE, 0);
+        gtk_container_add (GTK_CONTAINER(ralign), rbutton);
+        gtk_widget_show (rbutton);
 	gtk_widget_show (box);
 
         setup_mode(mfield, fsize);
