@@ -54,6 +54,12 @@
 #include "pix/gnome-dice-6.xpm"
 #include "pix/gnome-dice-none.xpm"
 
+/* Define a sensible alternative to ngettext if we don't have it. Note that
+ * this is only sensible in the context of gtali. */
+#ifndef HAVE_NGETTEXT
+#define ngettext(one,lots,n) gettext(lots)
+#endif
+
 int GyahtzeeAbort = 0;  /* Abort program without playing game */
 
 static char *appID="gtali";
@@ -114,7 +120,8 @@ CheerWinner(void)
 	ShowoffPlayer(ScoreList,winner,1);
 
         if (players[winner].name)
-                say(_("%s wins the game with %d points"),
+                say(ngettext("%s wins the game with %d point",
+                             "%s wins the game with %d points", WinningScore),
                     players[winner].name,
 		    WinningScore);
 	else
