@@ -409,8 +409,7 @@ void about_cb(GtkWidget *widget, gpointer data)
     	const gchar *translator_credits = _("translator_credits");
 	
 	if (about != NULL) {
-		gdk_window_raise (about->window);
-		gdk_window_show (about->window);
+                gtk_window_present (GTK_WINDOW (about));
 		return;
 	}
 
@@ -435,7 +434,9 @@ void about_cb(GtkWidget *widget, gpointer data)
 				strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				pixbuf);
 			
-			
+	if (pixbuf != NULL)
+		gdk_pixbuf_unref (pixbuf);
+				
 	g_signal_connect (GTK_OBJECT (about), "destroy", GTK_SIGNAL_FUNC
 			(gtk_widget_destroyed), &about);
 	gtk_window_set_transient_for (GTK_WINDOW(about), GTK_WINDOW(window));
