@@ -296,6 +296,7 @@ gboolean popup_warn = FALSE, popup_confirm = FALSE;
 GtkWidget *warn_cb = NULL, *confirm_cb = NULL;
 GtkWidget *colour_well = NULL;
 GtkWidget *pref_dialog = NULL;
+GtkWidget *about = NULL;
 
 typedef enum {
 	NEW_GAME,
@@ -670,7 +671,7 @@ mapset_changed_cb (GConfClient *client,
 		GTK_WINDOW (window),
 		GTK_DIALOG_MODAL,
 		GTK_MESSAGE_INFO,
-		GTK_BUTTONS_CLOSE,
+		GTK_BUTTONS_OK,
 		_("This new mapset will take effect when you start "
 		  "a new game, or when Mahjongg is restarted."));
 
@@ -1068,46 +1069,21 @@ you_won (void)
         gint pos;
         time_t seconds;
         gfloat score;
-        gchar *message;
-        gint response;
         GtkWidget *dialog;
-
+	
         game_over = GAME_WON;
 
         seconds = GAMES_CLOCK (chrono)->stopped;
 
         score = (seconds / 60) * 1.0 + (seconds % 60) / 100.0;
         if (pos = gnome_score_log (score, score_current_mapset, FALSE)) {
-                gnome_scores_display (_(APPNAME_LONG), APPNAME, score_current_mapset, pos);
-                message = g_strdup_printf
-			(_("Fantastic!  %.2f!\n"
-			   "You have reached #%d in the Top Ten.\n\n"
-			   "Another game?"), score, pos);
-        } else {
-                message = g_strdup_printf
-			(_("Great!\nYou made it in %.2f.\n\n"
-			   "Another game?"), score);
-	}
-
-	update_score_state ();
-       	
-       	dialog = gtk_message_dialog_new (
-		GTK_WINDOW (window),
-		GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-		GTK_MESSAGE_QUESTION,
-		GTK_BUTTONS_YES_NO,
-		message);
-
-       	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_YES);
-
-       	response = gtk_dialog_run (GTK_DIALOG (dialog));
-		
-       	gtk_widget_destroy (dialog);
-       	
-       	if (response == GTK_RESPONSE_YES) {
-		ensure_pause_off ();
-		new_game (TRUE);
-	}       	
+                dialog = gnome_scores_display (_(APPNAME_LONG), APPNAME, score_current_mapset, pos);
+		if (dialog != NULL) {
+			gtk_window_set_transient_for (GTK_WINDOW(dialog),
+						      GTK_WINDOW(window));
+			gtk_window_set_modal (GTK_WINDOW(dialog), TRUE);
+		}
+        } 
 }
 
 static void
@@ -1120,6 +1096,21 @@ pref_dialog_response (GtkDialog *dialog, gint response, gpointer data)
 	colour_well = NULL;
 }
 
+GtkWidget *
+bold_frame (gchar * title)
+{
+	gchar *markup;
+	GtkWidget * frame;
+	
+	markup = g_strdup_printf ("<b>%s</b>",title);
+	frame = gtk_frame_new(markup);
+	g_free(markup);
+	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
+	gtk_label_set_use_markup (GTK_LABEL (gtk_frame_get_label_widget(GTK_FRAME(frame))), TRUE);
+	
+	return frame;
+}
+
 void
 properties_callback (GtkWidget *widget, gpointer data)
 {
@@ -1149,9 +1140,7 @@ properties_callback (GtkWidget *widget, gpointer data)
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 8);
 
-	frame = gtk_frame_new(_("<b>Tiles</b>"));
-	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
-	gtk_label_set_use_markup (GTK_LABEL (gtk_frame_get_label_widget(GTK_FRAME(frame))), TRUE);
+	frame = bold_frame (_("Tiles"));
 
 	table = gtk_table_new (2, 2, FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (table), 8);
@@ -1184,9 +1173,7 @@ properties_callback (GtkWidget *widget, gpointer data)
 	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 0);
 
 
-	frame = gtk_frame_new(_("<b>Maps</b>"));
-	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
-	gtk_label_set_use_markup (GTK_LABEL (gtk_frame_get_label_widget(GTK_FRAME(frame))), TRUE);
+	frame = bold_frame (_("Maps"));
 
 	table = gtk_table_new (1, 2, FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (table), 8);
@@ -1208,9 +1195,7 @@ properties_callback (GtkWidget *widget, gpointer data)
 	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 0);
 
 
-	frame = gtk_frame_new(_("<b>Colours</b>"));
-	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
-	gtk_label_set_use_markup (GTK_LABEL (gtk_frame_get_label_widget(GTK_FRAME(frame))), TRUE);
+	frame = bold_frame (_("Colours"));
 
 	table = gtk_table_new (1, 2, FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (table), 8);
@@ -1237,9 +1222,7 @@ properties_callback (GtkWidget *widget, gpointer data)
 	gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 0);
 
 
-	frame = gtk_frame_new(_("<b>Warnings</b>"));
-	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
-	gtk_label_set_use_markup (GTK_LABEL (gtk_frame_get_label_widget(GTK_FRAME(frame))), TRUE);
+	frame = bold_frame (_("Warnings"));
 
 	table = gtk_vbox_new (FALSE, FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (table), 8);
@@ -1337,10 +1320,14 @@ hint_callback (GtkWidget *widget, gpointer data)
 	games_clock_start (GAMES_CLOCK(chrono));
 }
 
+void about_destroy (GtkWidget * widget, gpointer data)
+{
+	about = NULL;
+}
+
 void
 about_callback (GtkWidget *widget, gpointer data)
 {
-	GtkWidget *about;
 	GdkPixbuf *pixbuf = NULL;
 	const gchar *authors [] = {
 		"Code: Francisco Bustamante",
@@ -1371,7 +1358,11 @@ about_callback (GtkWidget *widget, gpointer data)
 		}
 	}
 
-
+	if (about) {
+		gtk_window_present (GTK_WINDOW (about));
+		return;
+	}
+	
 	about = gnome_about_new (_("GNOME Mahjongg"), VERSION,
 				 "(C) 1998 The Free Software Foundation",
 				  _("Send comments and bug reports to:\n"
@@ -1382,6 +1373,9 @@ about_callback (GtkWidget *widget, gpointer data)
 				 (const gchar **)documenters,
 				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				pixbuf);
+
+	g_signal_connect (G_OBJECT (about), "destroy",
+			  G_CALLBACK (about_destroy), NULL);
 	
 	if (pixbuf != NULL)
 		gdk_pixbuf_unref (pixbuf);
@@ -1432,7 +1426,14 @@ void ensure_pause_off (void)
 void
 scores_callback (GtkWidget *widget, gpointer data)
 {
-        gnome_scores_display (_(APPNAME_LONG), APPNAME, score_current_mapset, 0);
+	GtkWidget *dialog;
+
+	dialog = gnome_scores_display (_(APPNAME_LONG), APPNAME, score_current_mapset, 0);
+	if (dialog != NULL) {
+		gtk_window_set_transient_for (GTK_WINDOW(dialog),
+					      GTK_WINDOW(window));
+		gtk_window_set_modal (GTK_WINDOW(dialog), TRUE);
+	}
 }
 
 void
